aboutsummaryrefslogtreecommitdiffstats
path: root/idatui/remote_ops.py
diff options
context:
space:
mode:
Diffstat (limited to 'idatui/remote_ops.py')
-rw-r--r--idatui/remote_ops.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/idatui/remote_ops.py b/idatui/remote_ops.py
index 91ffeb7..a67b2b7 100644
--- a/idatui/remote_ops.py
+++ b/idatui/remote_ops.py
@@ -1,4 +1,4 @@
"""Typed remote operations executed through ida-codemode."""
from __future__ import annotations
# ruff: noqa
@@ -1655,7 +1655,7 @@ def _bindings() -> dict[Callable[..., Any], Any]:
with _BIND_LOCK:
if _BOUND is not None:
return _BOUND
- from ida_codemode import RemoteModule
+ from ida_nexus import RemoteModule
operations_module = RemoteModule(
Path(__file__), operation_label=operation_label, codec="json"
@@ -1,4 +1,4 @@
-"""Typed remote operations executed through ida-codemode."""
+"""Typed remote operations executed through ida-nexus."""
from __future__ import annotations
# ruff: noqa